aboutsummaryrefslogtreecommitdiff
path: root/src/ioHDF5GH.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/ioHDF5GH.h')
-rw-r--r--src/ioHDF5GH.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/ioHDF5GH.h b/src/ioHDF5GH.h
index 4af80f4..1c2fc5a 100644
--- a/src/ioHDF5GH.h
+++ b/src/ioHDF5GH.h
@@ -35,8 +35,8 @@ typedef struct
/* flag to indicate request for timer output */
int print_timing_info;
- /* hyperslab description list (for all variables) */
- ioSlab **slablist;
+ /* I/O request description list (for all variables) */
+ ioRequest **requests;
/* ring buffer for list of successfully created cp files */
int cp_filename_index;